@@ -35,16 +35,17 @@ define([
             super._init();
             /** Write codes executed before rendering */
             this.config.dataview = false;
-            this.config.sizeLevel = 1;
+            this.config.sizeLevel = 2;
             this.config.checkModules = ['pd'];
 
             this.fileExtensions = {
-                'csv': 'csv',
-                'excel': 'xlsx',
-                'json': 'json',
-                'pickle': '',
-                'sas': '', // xport or sas7bdat
-                'spss': ''
+                'csv': ['csv', 'tsv', 'txt'],
+                'excel': ['xlsx', 'xls'],
+                'json': ['json'],
+                'pickle': [],
+                'sas': [], // xport or sas7bdat
+                'spss': [],
+                'parquet': ['parquet']
             }
             
             this.package = {
@@ -68,7 +69,8 @@ define([
             }
 
             this.state = {
-                fileExtension: 'csv',
+                fileType: 'csv',
+                fileExtension: ['csv'],
                 selectedFile: '',
                 selectedPath: '',
                 vp_fileioType: 'Read',
@@ -90,7 +92,8 @@ define([
                         'json': 'pd_readJson',
                         'pickle': 'pd_readPickle',
                         'sas': 'pd_readSas',
-                        'spss': 'pd_readSpss'
+                        'spss': 'pd_readSpss',
+                        'parquet':'pd_readParquet'
                     },
                     selectedType: 'csv',
                     package: null,
@@ -104,7 +107,8 @@ define([
                         'csv': 'pd_toCsv',
                         'excel': 'pd_toExcel',
                         'json': 'pd_toJson',
-                        'pickle': 'pd_toPickle'
+                        'pickle': 'pd_toPickle',
+                        'parquet':'pd_toParquet'
                     },
                     selectedType: 'csv',
                     package: null,
@@ -185,6 +189,11 @@ define([
             }
         }
 
+        _unbindEvent() {
+            super._unbindEvent();
+            $(document).off('change', this.wrapSelector('#fileReadAs'));
+        }
+
         _bindEvent() {
             super._bindEvent();
             /** Implement binding events */
@@ -194,38 +203,74 @@ define([
                 that.state['vp_fileioType'] = pageType;
                 $(that.wrapSelector('.vp-fileio-box')).hide();
                 $(that.wrapSelector('#vp_file' + pageType)).show();
-    
-                //set fileExtensions
-                that.fileResultState = {
-                    ...that.fileState[pageType].fileResultState
-                };
-            });
-        }
 
-        _bindEventByType(pageType) {
-            var that = this;
-            var prefix = '#vp_file' + pageType + ' ';
-    
-            // select file type 
-            $(this.wrapSelector(prefix + '#fileType')).change(function() {
-                var value = $(this).val();
-                that.fileState[pageType].selectedType = value;
-    
-                // reload
-                that.renderPage(pageType);
-                that._bindEventByType(pageType);
-
-                if (value === 'spss') {
+                if (pageType === 'Read' && that.fileState[pageType].selectedType === 'spss') {
                     // show install button
                     that.showInstallButton();
                     // show install note below File type selection
-                    $(`<tr><td colspan="2">
+                    $(`<tr class="vp-spss-note"><td colspan="2">
                         <label class="vp-orange-text vp-italic">NOTE: </label>
                         <label class="vp-gray-text vp-italic">pyreadstat package is required to read spss file.</label>
                     </td></tr>`).insertAfter($(that.wrapSelector('#fileType')).closest('tr'));
                 } else {
                     that.hideInstallButton();
+                    $(that.wrapSelector('.vp-spss-note')).remove();
                 }
+
+
+                //set fileExtensions
+                that.fileResultState = {
+                    ...that.fileState[pageType].fileResultState
+                };
+            });
+
+            // fileReadAs change Event, Use PyArrow
+            $(document).on('change', this.wrapSelector('#fileReadAs'), function() {
+                let isChecked = $(this).prop('checked');
+                var fileioType = that.state.vp_fileioType;
+                var prefix = '#vp_file' + fileioType + ' ';
+                var selectedType = that.fileState[fileioType]['selectedType'];
+                var fileioTypePrefix = fileioType.toLowerCase();
+                if(fileioTypePrefix == 'write'){
+                    fileioTypePrefix = "to";
+                }
+                let fileId = that.fileState[fileioType].fileTypeId[selectedType];
+
+                if (isChecked) {  // pyArrow
+                    fileId = "pa_" + fileioTypePrefix + selectedType[0].toUpperCase() + selectedType.slice(1);
+                    // that.fileState[fileioType].fileTypeId[that.state.fileExtension] = "pa_" + fileioTypePrefix + selectedFileFormat[0].toUpperCase() + selectedFileFormat.slice(1);
+                    $(that.wrapSelector(prefix + '#vp_optionBox')).closest('.vp-accordian-container').hide();
+                } else {  // pandas
+                    // that.fileState[fileioType].fileTypeId[that.state.fileExtension] = "pd_" + fileioTypePrefix + selectedFileFormat[0].toUpperCase() + selectedFileFormat.slice(1);
+                    if (that.state.fileType != 'parquet'){  // parquet has no options area
+                        $(that.wrapSelector(prefix + '#vp_optionBox')).closest('.vp-accordian-container').show();
+                    }
+                }
+
+                let pdLib = pandasLibrary.PANDAS_FUNCTION;
+                let thisPkg = JSON.parse(JSON.stringify(pdLib[fileId]));
+                
+                that.fileState[fileioType].package = thisPkg;
+            });
+
+        }
+
+        _bindEventByType(pageType) {
+            var that = this;
+            var prefix = '#vp_file' + pageType + ' ';
+
+            var fileioTypePrefix = pageType.toLowerCase();
+            if(fileioTypePrefix == 'write'){
+                fileioTypePrefix = "to";
+            }
+            // select file type 
+            $(this.wrapSelector(prefix + '#fileType')).change(function() {
+                var fileType = $(this).val();
+                that.fileState[pageType].selectedType = fileType;
+    
+                // reload
+                that.renderPage(pageType);
+                that._bindEventByType(pageType);
             });
     
             // open file navigation
@@ -237,8 +282,8 @@ define([
                 }
 
                 let extensionList = [];
-                if (that.state.fileExtension !== '') {
-                    extensionList = [ that.state.fileExtension ];
+                if (that.state.fileExtension && that.state.fileExtension.length > 0) {
+                    extensionList = that.state.fileExtension;
                 }
 
                 let fileNavi = new FileNavigation({
@@ -327,7 +372,7 @@ define([
         renderPage(pageType) {
             var that = this;
             var prefix = '#vp_file' + pageType + ' ';
-    
+            
             // clear
             $(this.wrapSelector(prefix + '#vp_inputOutputBox table tbody')).html('');
             $(this.wrapSelector(prefix + '#vp_optionBox table tbody')).html('');
@@ -344,7 +389,7 @@ define([
                 ...this.fileState[pageType].fileResultState
             };
 
-            if (selectedType == 'pickle') {
+            if (selectedType == 'pickle' || selectedType == 'parquet') {
                 // hide additional option box
                 $(this.wrapSelector(prefix + '#vp_optionBox')).closest('.vp-accordian-container').hide();
             } else {
@@ -355,7 +400,7 @@ define([
                 if (selectedType == 'json') {
                     this.fileResultState.pathInputId = this.wrapSelector(prefix + '#path_or_buf');
                 }
-                if (selectedType == 'pickle') {
+                if (selectedType == 'pickle' || selectedType == 'parquet') {
                     this.fileResultState.pathInputId = this.wrapSelector(prefix + '#path');
                 }
             }
@@ -365,11 +410,21 @@ define([
             // pdGen.vp_showInterfaceOnPage(this.wrapSelector('#vp_file' + pageType), thisPkg);
             pdGen.vp_showInterfaceOnPage(this, thisPkg, this.state, parent=('#vp_file' + pageType));
     
+            // pyarrow can r/w parquet, csv and only read json.
+            if ((pageType == 'Read' && selectedType == 'json') || selectedType == 'parquet'|| selectedType == 'csv') {
+                // add checkbox 'Use PyArrow', next to File Type
+                $(this.wrapSelector(prefix + '#vp_inputOutputBox table tbody')).prepend(
+                    $('<tr>').append($(`<td><label for="fileType" class="vp-bold vp-orange-text">File Type</label></td>`))
+                            .append($('<td><select id="fileType" class="vp-select"></select>  <label><input id="fileReadAs" type="checkbox"/><span>Use PyArrow</span></label></td>'))
+                );
+            } else {
+                $(this.wrapSelector(prefix + '#vp_inputOutputBox table tbody')).prepend(
+                    $('<tr>').append($(`<td><label for="fileType" class="vp-bold vp-orange-text">File Type</label></td>`))
+                            .append($('<td><select id="fileType" class="vp-select"></select> </td>'))
+                );
+            }
+
             // prepend file type selector
-            $(this.wrapSelector(prefix + '#vp_inputOutputBox table tbody')).prepend(
-                $('<tr>').append($(`<td><label for="fileType" class="vp-bold vp-orange-text">File Type</label></td>`))
-                    .append($('<td><select id="fileType" class="vp-select"></select></td>'))
-            );
             var fileTypeList = Object.keys(fileTypeObj);
             fileTypeList.forEach(type => {
                 $(this.wrapSelector(prefix + '#fileType')).append(
@@ -390,9 +445,9 @@ define([
                         .append($('<td><input id="userOption" type="text" class="vp-input vp-state" placeholder="key=value, ..."/></td>'))
                 )
             }
-    
+
             $(this.wrapSelector(prefix + '#fileType')).val(selectedType);
-    
+
             // add file navigation button
             if (pageType == 'Write') {
                 if (selectedType == 'json') {
@@ -400,7 +455,7 @@ define([
                         com_util.formatString('<input type="text" class="vp-input vp-state" id="path_or_buf" index="0" placeholder="" value="" title=""><div id="vp_openFileNavigationBtn" class="{0}"></div>'
                         , 'vp-file-browser-button')
                     );
-                } else if (selectedType == 'pickle') {
+                } else if (selectedType == 'pickle'  || selectedType == 'parquet') {
                     $(prefix + '#path').parent().html(
                         com_util.formatString('<input type="text" class="vp-input vp-state" id="path" index="0" placeholder="" value="" title="" required="true"><div id="vp_openFileNavigationBtn" class="{0}"></div>'
                         , 'vp-file-browser-button')
@@ -419,6 +474,18 @@ define([
                         , 'vp-file-browser-button')
                 );
             }
+
+            if (pageType === 'Read' && selectedType === 'spss') {
+                // show install button
+                this.showInstallButton();
+                // show install note below File type selection
+                $(`<tr class="vp-spss-note"><td colspan="2">
+                    <label class="vp-orange-text vp-italic">NOTE: </label>
+                    <label class="vp-gray-text vp-italic">pyreadstat package is required to read spss file.</label>
+                </td></tr>`).insertAfter($(this.wrapSelector('#fileType')).closest('tr'));
+            } else {
+                this.hideInstallButton();
+            }
     
             // encoding suggest input
             $(this.wrapSelector('#encoding')).replaceWith(function() {
@@ -431,6 +498,18 @@ define([
                 suggestInput.setPlaceholder('encoding option');
                 return suggestInput.toTagString();
             });
+
+            // seperator suggest input
+            $(this.wrapSelector('#sep')).replaceWith(function() {
+                // seperator list : 
+                var sepList = [',', '|', '\\t', '\\n', ':', ';', '-', '_', '&', '/', '\\'];
+                var suggestInput = new SuggestInput();
+                suggestInput.setComponentID('sep');
+                suggestInput.addClass('vp-input vp-state');
+                suggestInput.setSuggestList(function() { return sepList; });
+                suggestInput.setPlaceholder('Input seperator');
+                return suggestInput.toTagString();
+            });
         }
 
         render() {
@@ -493,7 +572,6 @@ define([
                 var result = pdGen.vp_codeGenerator(this, thisPkg, this.state, userOption.toString(), parent='#vp_fileWrite');
                 sbCode.append(result);
             }
-
             return sbCode.toString();
         }
 
